@@ -25,9 +25,9 @@ bs_sass_file <- function(file, version) {
 
   f <- switch_version(
     version,
-    five = lib_file("bs5", "scss", file),
-    four = lib_file("bs4", "scss", file),
-    three = lib_file("bs3", "assets", "stylesheets", "bootstrap", file)
+    five = path_lib("bs5", "scss", file),
+    four = path_lib("bs4", "scss", file),
+    three = path_lib("bs3", "assets", "stylesheets", "bootstrap", file)
   )
   if (f == "") stop("The bootstrap stylesheet '", file, "' doesn't exist.", call. = FALSE)
   sass_file(f)
@@ -46,6 +46,7 @@ bootswatch_sass_file <- function(theme, file, version = version_default()) {
 # Given a vector of sass_file()s, create a list of sass_bundles(),
 # so each rule may be removed layer (by it's files basename)
 rule_bundles <- function(files) {
+  files <- lapply(files, as_sass_file)
   paths <- vapply(files, get_sass_file_path, character(1))
   nms <- tools::file_path_sans_ext(basename(paths))
   Map(
@@ -62,3 +63,7 @@ get_sass_file_path <- function(x) {
 
   stop("Couldn't find file path")
 }
+
+as_sass_file <- function(x) {
+  if (inherits(x, "sass_file")) x else sass_file(x)
+}
